@@ -1114,7 +1114,7 @@ void find_nearest_ac(struct acs* acs, int mouse_x, int mouse_y, double* min, cha
     if (!acs) return;
 
     struct subwin* sw = gses->ontop;
-    if (sw->type != SWT_MAP) return;
+    if (sw->type != SWT_MAP && sw->type != SWT_KST) return;
 
     int px = mouse_x - sw->x * FONT_W;
     int py = mouse_y - sw->y * FONT_H;
