@@ -1,7 +1,7 @@
 
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2023  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -32,12 +32,14 @@ struct memory_list *getml(void *p, ...)
     void *q = p;
     va_start(ap, p);
     while (q) n++, q = va_arg(ap, void *);
+    va_end(ap);
     if (!(ml = (struct memory_list*)g_malloc(sizeof(struct memory_list) + n * sizeof(void *)))) return NULL;
     ml->n = n;
     n = 0;
     q = p;
     va_start(ap, p);
     while (q) ml->p[n++] = q, q = va_arg(ap, void *);
+    va_end(ap);
     return ml;
 }
 
@@ -393,7 +395,8 @@ static void display_mainmenu(struct mainmenu *menu)
     int i;
     int p = 2;
     fill_area(0, 0, term->x, 1, COLOR_MAINMENU | ' ');
-    for (i = 0; menu->items[i].text; i++) {
+	set_char(0, 0, COLOR_MAINMENU | 0xad);
+	for (i = 0; menu->items[i].text; i++) {
         int s = 0;
         int j;
         unsigned char c;
@@ -495,6 +498,9 @@ void mainmenu_func(struct window *win, struct event *ev, int fwd)
     }
 }
 
+// free_i:
+// 0x02 - free text
+// 0x04 - free rtext
 struct menu_item *new_menu(int free_i)
 {
     struct menu_item *mi;
@@ -1480,6 +1486,7 @@ void msg_box(struct memory_list *ml, char *title,
         na_kovarne__to_je_narez:
         if (!(udata_ = g_realloc(udata, ++udatan * sizeof(char *)))) {
             g_free(udata);
+            va_end(ap);
             return;
         }
         udata = udata_;
@@ -1493,6 +1500,7 @@ void msg_box(struct memory_list *ml, char *title,
     n = va_arg(ap, int);
     if (!(dlg = g_malloc(sizeof(struct dialog) + (n + 1) * sizeof(struct dialog_item)))) {
         g_free(udata);
+        va_end(ap);
         return;
     }
     memset(dlg, 0, sizeof(struct dialog) + (n + 1) * sizeof(struct dialog_item));
@@ -1519,6 +1527,7 @@ void msg_box(struct memory_list *ml, char *title,
         dlg->items[i].text = m;
         dlg->items[i].udata = fn;
     }
+    va_end(ap);
     dlg->items[i].type = D_END;
     add_to_ml(&ml, dlg, udata, NULL);
     do_dialog(dlg, ml);
