@@ -46,7 +46,7 @@ int export_all_bands_cbr(void){
     int ignoreerror=0;
     int psect = 2; // 0=Multi, 1=Single, 2=Check
     char *ope[] = {"MULTI-OP", "SINGLE-OP", "CHECKLOG"};
-    char *mode[] = {"CW", "DIGI", "FM", "RTTY", "SSB", "MIXED"};
+    char *mode[] = {"CW", "DIGI", "FM", "MGM", "SSB", "MIXED"};
     char *ass[] = {"ASSISTED", "NON-ASSISTED", "ASSISTED"};
     int maxpower = 0;
     char *powerstr = "HIGH";
