@@ -28,10 +28,8 @@
 #include "tregex.h"
 #include "zosk.h"
 
-char *kst_servers[] = {"www.on4kst.info", 
-                       "on4kst.dyndns.org", 
-					   "141.94.171.16", // www.on4kst.info 22.11.2021
-					   //"188.165.198.144", // www.on4kst.info 11.3.2015
+char *kst_servers[] = {"www.on4kst.org", 
+					   "5.196.193.63", // www.on4kst.org 13.12.2025
                        NULL};
 int kst_i = 0;
 
