@@ -374,6 +374,7 @@ char ac_maxelev_str[DBL_LEN];
 char ac_mindur_str[DBL_LEN];       
 char ac_maxdelta_str[DBL_LEN];  
 char ac_minalt_str[DBL_LEN];
+char ac_minwingspan_str[DBL_LEN];
 int ac_imperial;
 char kst_maxqrb_str[MAX_STR_LEN];
 
@@ -418,7 +419,8 @@ void refresh_ac_opts(void *arg){
     STORE_SDBL(cfg, ac_maxelev);
     STORE_SINT(cfg, ac_mindur);
     STORE_SDBL(cfg, ac_maxdelta);
-	STORE_SINT(cfg, ac_minalt);
+    STORE_SINT(cfg, ac_minalt);
+    STORE_SINT(cfg, ac_minwingspan);
 	STORE_INT(cfg, ac_imperial);
 	STORE_SINT(cfg, kst_maxqrb);
 
@@ -455,6 +457,7 @@ void menu_ac_opts(void *arg){
     g_snprintf(ac_mindur_str,  DBL_LEN, "%d", cfg->ac_mindur);
     g_snprintf(ac_maxdelta_str, DBL_LEN, "%3.1f", cfg->ac_maxdelta);
     g_snprintf(ac_minalt_str, DBL_LEN, "%d", cfg->ac_minalt);
+    g_snprintf(ac_minwingspan_str, DBL_LEN, "%d", cfg->ac_minwingspan);
     LOAD_INT(cfg, ac_imperial);
 	LOAD_SINT(cfg, kst_maxqrb);
 
@@ -621,6 +624,15 @@ void menu_ac_opts(void *arg){
     d->items[i].gid  = 0;
     d->items[i].gnum = 20000;
     d->items[i].msg = TRANSLATE("Minimal AS altitude [m]");
+    d->items[i].wrap = 1;
+
+    d->items[++i].type = D_FIELD;
+    d->items[i].dlen = 6;
+    d->items[i].data = (char*)&ac_minwingspan_str;
+    d->items[i].fn = check_number;
+    d->items[i].gid = 0;
+    d->items[i].gnum = 200;
+    d->items[i].msg = TRANSLATE("Minimal aircraft wingspan [m]");
     d->items[i].wrap = 1;
 
 	d->items[++i].type = D_CHECKBOX;
