@@ -62,7 +62,7 @@
 #define HAVE_PORTAUDIO
 #define HAVE_LIBFFTW3
 #define HAVE_HAMLIB
-#define HAVE_LIBRTLSDR
+#undef HAVE_LIBRTLSDR
 #define HAVE_HIDAPI
 #define HAVE_SHLOBJ_H
 #define HAVE_RIG_SEND_VOICE_MEM
