@@ -256,7 +256,7 @@ void trigs_set_ptt(struct trigs *trigs, int ptt){
 		struct trig *trig;
 		trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
 		if (trig->ptt_t2r != 0) {
-            trig_set_ptt(trig, ptt ? trig->ptt_t2r : RIG_PTT_OFF);
+            trig_set_ptt(trig, ptt ? (ptt_t)trig->ptt_t2r : RIG_PTT_OFF);
         }
 	}
 }
@@ -360,6 +360,7 @@ struct trig *init_trig(struct config_rig *crig){
 	trig->clr_rit = crig->rig_clr_rit;
 	trig->ptt_t2r = crig->rig_ptt_t2r;
 	trig->conf = g_strdup(crig->rig_conf);
+	for (int m = 0; m < TRIG_MAX_MODE; m++) trig->mode2bandwidth[m] = RIG_PASSBAND_NORMAL;
 
     MUTEX_INIT(trig->jobs);
    
@@ -631,7 +632,6 @@ gpointer trig_main(gpointer xxx){
     while(!trig->thread_break){
         struct trig_job *job;
         rmode_t mode;
-        pbwidth_t width;
         vfo_t vfo;
 
         if (trig->rigerr == -RIG_EIO){
@@ -703,14 +703,26 @@ gpointer trig_main(gpointer xxx){
 		switch (job->cmd){
 			case TRIG_MODE:
 				usleep(trig->poll_ms * 1000);
+				pbwidth_t width;
 				rigerr = rig_get_mode(trig->rig, RIG_VFO_CURR, &mode, &width);
 				if (rigerr != RIG_OK) {
 					gtrigs->rigerr = trig->rigerr = rigerr;
 					TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)", trig->nr);
 					break;
 				}
+				TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)  m=%s  bw=%ld", trig->nr, rig_strrmode(mode), (long)width);
+
+				if (mode >= 0 && mode < TRIG_MAX_MODE) {
+					trig->mode2bandwidth[mode] = width;
+				}
+
 				usleep(trig->poll_ms * 1000);
-				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
+
+				width = RIG_PASSBAND_NORMAL;
+				if (job->mode > 0 && job->mode < TRIG_MAX_MODE) {
+					width = trig->mode2bandwidth[job->mode];
+				}
+				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width);
 				TRTR(1, "rig_set_mode(#%d, RIG_VFO_CURR, %s, %ld)", trig->nr, rig_strrmode(job->mode), width);
 				if (rigerr != RIG_OK) {
 					gtrigs->rigerr = trig->rigerr = rigerr;
@@ -735,11 +747,21 @@ gpointer trig_main(gpointer xxx){
 					TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)", trig->nr);
 					break;
 				}
-				//dbg("mode=%d job->mode=%d\n", mode, job->mode);
-				if (mode == job->mode) break;
+				TRTR(1, "rig_get_mode(#%d, RIG_VFO_CURR)  m=%s  bw=%ld", trig->nr, rig_strrmode(mode), (long)width);
+
+				if (mode >= 0 && mode < TRIG_MAX_MODE) {
+					trig->mode2bandwidth[mode] = width;
+				}
+				
 				usleep(trig->poll_ms * 1000);
-				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width /*RIG_PASSBAND_NORMAL*/);
-				TRTR(1, "rig_set_mode(#%d, RIG_VFO_CURR, %s, %ld", trig->nr, rig_strrmode(job->mode), width);
+				
+				width = RIG_PASSBAND_NORMAL;
+				if (job->mode > 0 && job->mode < TRIG_MAX_MODE) {
+					width = trig->mode2bandwidth[job->mode];
+				}
+
+				rigerr = rig_set_mode(trig->rig, RIG_VFO_CURR, job->mode, width);
+				TRTR(1, "rig_set_mode(#%d, RIG_VFO_CURR, %s, %ld)", trig->nr, rig_strrmode(job->mode), width);
 				if (rigerr != RIG_OK) {
 					gtrigs->rigerr = trig->rigerr = rigerr;
 					break;
